@@ -19,14 +19,13 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rijndael-128.c,v 1.11 2001/09/09 09:52:54 nmav Exp $ */
+/* $Id: rijndael-128.c,v 1.12 2002/03/09 20:29:04 nmav Exp $ */
 
 #include <libdefs.h>
 
 #include <mcrypt_modules.h>
 #include "rijndael.h"
 
-#ifdef USE_LTDL
 #define _mcrypt_set_key rijndael_128_LTX__mcrypt_set_key
 #define _mcrypt_encrypt rijndael_128_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt rijndael_128_LTX__mcrypt_decrypt
@@ -38,7 +37,6 @@
 #define _mcrypt_get_algorithms_name rijndael_128_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test rijndael_128_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version rijndael_128_LTX__mcrypt_algorithm_version
-#endif
 
 /* rotates x one bit to the left */
 
